pub enum CacheKind {
HyperscanShards,
DetectorPlans,
GpuPrograms,
MatcherArtifacts,
LockFiles,
}Expand description
All distinct cache artifact kinds managed by KeyHog.
Variants
HyperscanShards
Hyperscan / Vectorscan compiled regex pattern shard databases (hs-<key>.db).
DetectorPlans
Pre-parsed detector corpus JSON plans (detectors-<key>.json).
GpuPrograms
Compiled GPU literal-set binary matchers (programs/*).
MatcherArtifacts
Eager compiled matcher artifact graphs (*.khm).
LockFiles
Inter-process write and synchronization lock files (*.lock).
Implementations
Sourceimpl CacheKind
impl CacheKind
Sourcepub fn matches_path(self, path: &Path) -> bool
pub fn matches_path(self, path: &Path) -> bool
Check whether a given filename or path matches this cache kind.
Sourcepub fn classify_path(path: &Path) -> Option<Self>
pub fn classify_path(path: &Path) -> Option<Self>
Classify a path into its respective CacheKind if recognized.
Sourcepub const fn default_policy(self) -> CacheEvictionPolicy
pub const fn default_policy(self) -> CacheEvictionPolicy
Return the canonical default eviction policy for this cache kind.