pub enum DetectorCorpusMode {
Replace,
Overlay,
}Expand description
How a custom detector corpus participates in the effective corpus.
Variants
Replace
The custom corpus is the complete effective corpus.
Overlay
The custom corpus is appended to the embedded corpus after collision checks.