pub enum EvidenceValueRelation {
Present,
EqualsPrimary,
DiffersFromPrimary,
}Expand description
The value relationship between a selected evidence capture and the primary credential.
Variants
Present
Presence inside the declared structural and distance bounds is sufficient.
EqualsPrimary
The selected evidence bytes must exactly equal the primary credential.
DiffersFromPrimary
The selected evidence bytes must differ from the primary credential.
Implementations