pub fn load_detector_corpus(
dir: &Path,
) -> Result<LoadedDetectorCorpus, SpecError>Expand description
Load all detector specs together with their normalized corpus schema identity.
pub fn load_detector_corpus(
dir: &Path,
) -> Result<LoadedDetectorCorpus, SpecError>Load all detector specs together with their normalized corpus schema identity.