pub fn load_detectors(dir: &Path) -> Result<Vec<DetectorSpec>, SpecError>Expand description
Load all detector specs from a directory of TOML files. Runs the quality gate on each detector and fails closed if any detector cannot be read, parsed, or accepted by the gate.
Examples
use keyhog_core::load_detectors;
use std::path::Path;
let detectors = load_detectors(Path::new("detectors"))?;
assert!(!detectors.is_empty());