pub fn write_report<W: Write + Send>(
writer: W,
format: ReportFormat,
findings: &[VerifiedFinding],
) -> Result<(), ReportError>Expand description
Write a complete findings report in the requested format.
pub fn write_report<W: Write + Send>(
writer: W,
format: ReportFormat,
findings: &[VerifiedFinding],
) -> Result<(), ReportError>Write a complete findings report in the requested format.