pub enum GuardStoreError {
SchemaTooNew {
found: u32,
supported: u32,
},
SchemaObsolete {
found: u32,
},
Corrupt {
detail: String,
},
UnsafePath {
detail: String,
},
Io(String),
UncleanShutdown,
}Expand description
Error returned by the guard store.
Variants
SchemaTooNew
The store schema version is newer than this binary supports.
Fields
SchemaObsolete
The store schema version is older than this binary supports and cannot be migrated.
Corrupt
The store file is corrupt or truncated.
UnsafePath
The store path has unsafe ownership or permissions.
Io(String)
An I/O error occurred.
UncleanShutdown
The store was not started cleanly (previous process may not have flushed).