pub fn validate(selector: &str) -> Result<(), SelectorError>Expand description
Validate the rooted response selector grammar used by detector TOMLs.
pub fn validate(selector: &str) -> Result<(), SelectorError>Validate the rooted response selector grammar used by detector TOMLs.