pub struct DetectorRelationSpec {
pub detector_id: String,
pub kind: DetectorRelationKind,
pub within_lines: usize,
pub within_bytes: Option<usize>,
pub direction: EvidenceDirection,
}Expand description
A bounded relationship between findings from two detector owners.
Fields
detector_id: StringStable target detector ID.
kind: DetectorRelationKindResolution operation performed when target evidence is present or absent.
within_lines: usizeMaximum absolute line distance between source and target findings.
within_bytes: Option<usize>Optional maximum byte gap between source and target finding spans.
direction: EvidenceDirectionDirection of the target finding relative to this detector’s finding.