pub struct TriageEnvelope {
pub version: u32,
pub detector_digest: String,
pub records: Vec<TriageRecord>,
}Expand description
Redacted findings submitted for triage.
Fields
version: u32Schema version. Only the current version is accepted.
detector_digest: StringExact effective detector corpus identity emitted by the producing binary.
records: Vec<TriageRecord>Bounded redacted records.
Implementations
Sourceimpl TriageEnvelope
impl TriageEnvelope
Sourcepub fn from_json(
bytes: &[u8],
expected_detector_digest: &str,
) -> Result<Self, String>
pub fn from_json( bytes: &[u8], expected_detector_digest: &str, ) -> Result<Self, String>
Parse and validate the current redacted contract for one active corpus.
Sourcepub fn validate(&self, expected_detector_digest: &str) -> Result<(), String>
pub fn validate(&self, expected_detector_digest: &str) -> Result<(), String>
Validate versions, bounds, identities, and reason/disposition coherence.
Sourcepub fn into_outputs(self) -> (RuntimeSuppressions, PatternFeedback)
pub fn into_outputs(self) -> (RuntimeSuppressions, PatternFeedback)
Derive distinct runtime-suppression and pattern-feedback artifacts.