pub fn apply_protections(lockdown: bool) -> HardeningReportExpand description
Apply the process protections for the requested security mode.
When lockdown is true, this also fails closed on persisted keyhog cache
artifacts that could expose past findings.