pub struct RootRegistry { /* private fields */ }Expand description
In-memory root registry. The durable store persists these records; this holds the live state for the daemon scheduler.
Implementations
Sourceimpl RootRegistry
impl RootRegistry
Sourcepub fn register(
&mut self,
canonical_path: Vec<u8>,
filesystem_identity: FilesystemIdentity,
mode: GuardRootMode,
) -> GuardRootRecord
pub fn register( &mut self, canonical_path: Vec<u8>, filesystem_identity: FilesystemIdentity, mode: GuardRootMode, ) -> GuardRootRecord
Register a new root. Returns the initial record in Stopped state.
Sourcepub fn insert_record(&mut self, record: GuardRootRecord)
pub fn insert_record(&mut self, record: GuardRootRecord)
Insert a fully-formed root record. Used when restoring from
the durable store, where the complete record state must be
preserved rather than initialized to Stopped.
Sourcepub fn get(&self, canonical_path: &[u8]) -> Option<&GuardRootRecord>
pub fn get(&self, canonical_path: &[u8]) -> Option<&GuardRootRecord>
Look up a root by canonical path bytes.
Sourcepub fn get_mut(&mut self, canonical_path: &[u8]) -> Option<&mut GuardRootRecord>
pub fn get_mut(&mut self, canonical_path: &[u8]) -> Option<&mut GuardRootRecord>
Look up a root by canonical path bytes for mutation.
Sourcepub fn remove(&mut self, canonical_path: &[u8]) -> Option<GuardRootRecord>
pub fn remove(&mut self, canonical_path: &[u8]) -> Option<GuardRootRecord>
Remove a root from the registry.
Sourcepub fn list(&self) -> Vec<&GuardRootRecord>
pub fn list(&self) -> Vec<&GuardRootRecord>
List all registered roots.
Sourcepub fn count_by_state(&self, state: GuardRootState) -> usize
pub fn count_by_state(&self, state: GuardRootState) -> usize
Count roots by state.