pub struct MatchLocation {
pub source: String,
pub file_path: Option<String>,
pub line: Option<usize>,
pub offset: usize,
pub commit: Option<String>,
pub author: Option<String>,
pub date: Option<String>,
}Expand description
Where a credential was found: file path, line number, commit, and author.
Examples
use keyhog_core::MatchLocation;
let location = MatchLocation {
source: "stdin".into(),
file_path: None,
line: Some(3),
offset: 20,
commit: None,
author: None,
date: None,
};
assert_eq!(location.line, Some(3));Fields
source: StringLogical source backend, such as filesystem or git.
file_path: Option<String>File path, object key, or logical path when available.
line: Option<usize>One-based line number when known.
offset: usizeByte offset from the start of the source chunk.
commit: Option<String>Commit identifier for history-derived matches.
Commit author when available.
date: Option<String>Commit timestamp when available.